@@ -33,7 +33,6 @@ describe 'cinder' do
 
     it 'should contain default config' do
       is_expected.to contain_cinder_config('DEFAULT/transport_url').with(:value => '<SERVICE DEFAULT>')
-      is_expected.to contain_cinder_config('DEFAULT/rpc_backend').with(:value => 'rabbit')
       is_expected.to contain_cinder_config('DEFAULT/rpc_response_timeout').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_cinder_config('DEFAULT/control_exchange').with(:value => 'openstack')
       is_expected.to contain_cinder_config('DEFAULT/report_interval').with(:value => '<SERVICE DEFAULT>')
@@ -180,11 +179,7 @@ describe 'cinder' do
     it { is_expected.to contain_cinder_config('oslo_messaging_rabbit/amqp_durable_queues').with_value(true) }
   end
 
-  describe 'with amqp rpc_backend defaults' do
-    let :params do
-      { :rpc_backend => 'amqp' }
-    end
-
+  describe 'with amqp defaults' do
     it 'configures amqp' do
       is_expected.to contain_cinder_config('oslo_messaging_amqp/server_request_prefix').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_cinder_config('oslo_messaging_amqp/broadcast_prefix').with_value('<SERVICE DEFAULT>')
@@ -205,10 +200,9 @@ describe 'cinder' do
     end
   end
 
-  describe 'with amqp rpc_backend overrides' do
+  describe 'with amqp overrides' do
     let :params do
     {
-      :rpc_backend        => 'amqp',
       :amqp_idle_timeout  => '60',
       :amqp_trace         => true,
       :amqp_ssl_ca_file   => '/path/to/ca.cert',
