@@ -24,6 +24,7 @@ describe 'cinder::logging' do
      :instance_uuid_format => '[instance: %(uuid)s] ',
      :log_date_format => '%Y-%m-%d %H:%M:%S',
      :use_syslog => true,
+     :use_json => true,
      :use_stderr => false,
      :log_facility => 'LOG_FOO',
      :log_dir => '/var/log',
@@ -57,6 +58,7 @@ describe 'cinder::logging' do
     it 'configures cinder logging settings with default values' do
       is_expected.to contain_oslo__log('cinder_config').with(
         :use_syslog => '<SERVICE DEFAULT>',
+        :use_json   => '<SERVICE DEFAULT>',
         :use_stderr => '<SERVICE DEFAULT>',
         :log_dir    => '/var/log/cinder',
         :debug      => '<SERVICE DEFAULT>',
@@ -68,6 +70,7 @@ describe 'cinder::logging' do
     it 'configures cinder logging settings with non-default values' do
       is_expected.to contain_oslo__log('cinder_config').with(
         :use_syslog          => true,
+        :use_json            => true,
         :use_stderr          => false,
         :syslog_log_facility => 'LOG_FOO',
         :log_dir             => '/var/log',
