@@ -37,6 +37,7 @@ describe 'cinder::backend::rbd' do
 
   describe 'rbd backend volume driver' do
     it 'configure rbd volume driver' do
+      is_expected.to contain_package('ceph-common').with(:ensure => :present)
       is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/volume_backend_name").with_value(req_params[:volume_backend_name])
       is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/volume_driver").with_value('cinder.volume.drivers.rbd.RBDDriver')
       is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/rbd_ceph_conf").with_value(req_params[:rbd_ceph_conf])
@@ -55,7 +56,7 @@ describe 'cinder::backend::rbd' do
       is_expected.to contain_file_line('set initscript env rbd-ssd').with(
         :line    => /env CEPH_ARGS=\"--id test\"/,
         :path    => '/etc/init/cinder-volume.override',
-        :notify  => 'Service[cinder-volume]')
+        :notify  => 'Anchor[cinder::service::begin]')
     end
 
     context 'with another RBD backend' do
@@ -127,7 +128,7 @@ describe 'cinder::backend::rbd' do
       is_expected.to contain_file_line('set initscript env rbd-ssd').with(
         :line    => /export CEPH_ARGS=\"--id test\"/,
         :path    => '/etc/sysconfig/openstack-cinder-volume',
-        :notify  => 'Service[cinder-volume]')
+        :notify  => 'Anchor[cinder::service::begin]')
     end
   end
 
